/* vi:set et ai sw=2 sts=2 ts=2: */
/*-
 * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __THUNAR_RENAMER_DIALOG_H__
#define __THUNAR_RENAMER_DIALOG_H__

#include "thunar/thunar-file.h"

G_BEGIN_DECLS;

typedef struct _ThunarRenamerDialogClass ThunarRenamerDialogClass;
typedef struct _ThunarRenamerDialog      ThunarRenamerDialog;

#define THUNAR_TYPE_RENAMER_DIALOG (thunar_renamer_dialog_get_type ())
#define THUNAR_RENAMER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_RENAMER_DIALOG, ThunarRenamerDialog))
#define THUNAR_RENAMER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_RENAMER_DIALOG, ThunarRenamerDialogClass))
#define THUNAR_IS_RENAMER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_RENAMER_DIALOG))
#define THUNAR_IS_RENAMER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_RENAMER_DIALOG))
#define THUNAR_RENAMER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_RENAMER_DIALOG, ThunarRenamerDialogClass))

GType
thunar_renamer_dialog_get_type (void) G_GNUC_CONST;

void
thunar_show_renamer_dialog (gpointer     parent,
                            ThunarFile  *current_directory,
                            GList       *files,
                            gboolean     standalone,
                            const gchar *startup_id);

G_END_DECLS;

#endif /* !__THUNAR_RENAMER_DIALOG_H__ */
